import { useState } from 'react';

import s from './TimerContainer.module.css';
import TimerControl from './TimerControl/TimerControl';
import Timer from './Timer/Timer';

interface IRenderProps {
  seconds: number;
  refresh: number;
}

interface ITimerContainerProps {
  amountMs: number;
  refresh: number;
  render: ({ seconds, refresh }: IRenderProps) => JSX.Element;
}
const TimerContainer = ({
  amountMs,
  refresh,
  render,
}: ITimerContainerProps) => {
  const [flag, setFlag] = useState<string>('Start');
  const [refreshMs, setRefreshMs] = useState<number>(0);
  const [hours, setHours] = useState<number>(0);
  const [minutes, setMinutes] = useState<number>(0);
  const [seconds, setSeconds] = useState<number>(0);

  const time = (hours * 60 + minutes) * 60 + seconds;

  return (
    <div className={s.timerContainerWrapper}>
      <Timer
        time={time === 0 ? amountMs / 1000 : time}
        flag={flag}
        setFlag={setFlag}
        refresh={refreshMs === 0 ? refresh : refreshMs * 100}
        render={render}
      />
      <TimerControl
        flag={flag}
        setRefreshMs={setRefreshMs}
        setHours={setHours}
        setMinutes={setMinutes}
        setSeconds={setSeconds}
      />
    </div>
  );
};

export default TimerContainer;
